@@ -245,8 +245,6 @@ class DeviceConnector:
         this method call will not execute until the event completes.
         """
         device.ppadb.shell(event.get_cmd_str())
-
-    # TODO: Maybe in the future, make methods so that events can be sent asynchronously
     
     def get_screen_capture(self, device: Device,
             save_path: Optional[str] = "screen.png") -> None:
@@ -460,11 +458,12 @@ class DeviceConnector:
         process.kill()
         print('Stopped recording events on device "' + device.serial + '"')
     
-    def get_window_at(self, device: Device, x: int, y: int) -> str:
+    def get_keyboard_bounds(self,
+            device: Device) -> Optional[Tuple[Tuple[int, int], Tuple[int, int]]]:
     	"""
-    	Returns the name of the current window at the given x and y coordinates on the given device.
-    	The return value will be "Keyboard" if the coordinates are within the device's software
-    	keyboard; otherwise, "Main" will be returned.
+    	Returns the bounds of the software keyboard on the device formatted like
+        ((x1, y1), (x2, y2)) if the keybaoard is showing. If the keyboard is not showing, then None
+        is returned.
     	"""
 
     	# get the output of the shell command that gives information about the keyboard
@@ -474,9 +473,8 @@ class DeviceConnector:
     	match = re.search(r"mHasSurface=(true|false)", output)
 
     	if match:
-    		
-    		# If the keyboard is displayed, check the given x and y coordinates against the
-    		# coordinates given by the "touchable region" part of the output.
+
+            # if the keyboard is displayed, then try to extract the bounds info from the output
     		if match.group(1) == "true":
 
     			match = re.search(r"touchable region=SkRegion\(\((\d+),(\d+),(\d+),(\d+)\)\)",
@@ -484,17 +482,16 @@ class DeviceConnector:
     			
     			if match:
     				
-    				# if the x and y coords are within the touchable region, then return "Keyboard"
+    				# get the bounds and return them
     				x1 = int(match.group(1)) 
     				y1 = int(match.group(2)) 
     				x2 = int(match.group(3)) 
     				y2 = int(match.group(4))
     				
-    				if x1 <= x <= x2 and y1 <= y <= y2:
-    					return "Keyboard"
+    				return ((x1, y1), (x2, y2))
 
-    	# default to returning "Main"	
-    	return "Main"
+    	# default to returning None	
+    	return None
 
     def get_current_activity(self, device: Device) -> Optional[str]:
     	"""
@@ -578,7 +575,7 @@ class DeviceConnector:
         
         return pk_list
     
-    def app_is_installed(self, device: Device, package_name: str) -> bool:
+    def app_is_installed(self, device: Device, package_name: Optional[str]) -> bool:
         """
         Returns True if the given app (package) is installed on the given device; returns False
         otherwise.
